All Classes and Interfaces
Class
Description
Thrown in case a proxy for a given type was requested but more than one proxy
matched the requested type.
The most common information to be provided when describing an object residing
in a
RemoteServer and which is linked to a RemoteClient.The Interface ClientMessage.
The Class
DuplicateInstanceIdRuntimeException.The Class
DuplicateSessionIdRuntimeException.Provides an accessor for a
ClassDescriptor property.Provides a builder method for the according property returning the
builder for applying multiple build operations.
Provides a mutator for a
ClassDescriptor property.Provides a
ClassDescriptor property.The
InstanceId associates an instance ID to instances of the
refcodes-remoting frame.Thrown in case the provided
Message sub-type was not expected and
cannot be processed.The Class
InvalidMethodRequestRuntimeException.The
Message is the base definition for any job required by the inter
process communication as done by the refcodes-remoting artifact.The Interface MethodRequest.
Thrown in case a proxy for a given type was requested but not any proxy
matched the requested type.
Provides an accessor for a proxy property.
Provides a builder method for the according property returning the
builder for applying multiple build operations.
Provides a mutator for a proxy property.
Provides a proxy property.
This is a predictable exception.
The
Remote interface defines the basic functionality in common for
both the RemoteClient and the RemoteServer.A
RemoteClient promotes subjects to be operated on by a
RemoteServer.A
RemoteServer promotes subjects to be operated on by
RemoteClient instances.The Class
RemotingException.The Class
RemotingRuntimeException.The Interface Reply.
Utility providing useful serialization methods.
The Interface ServerMessage.
The
Session associates an ID String to sessions of request and reply
pairs.Provides an accessor for a session ID property.
Provides a builder method for a the according property returning the
builder for applying multiple build operations.
Provides a mutator for a session ID property.
Provides a session ID property.
Provides an accessor for a subject property.
Provides a builder method for the according property returning the
builder for applying multiple build operations.
Provides a mutator for a subject property.
Provides a subject property.
Thrown in case an instance ID has been provided which is unknown by the
processing instance.