Class AmbiguousProxyException

java.lang.Object
java.lang.Throwable
java.lang.Exception
org.refcodes.exception.AbstractException
org.refcodes.remoting.RemotingException
org.refcodes.remoting.AmbiguousProxyException
All Implemented Interfaces:
Serializable, org.refcodes.exception.ErrorCodeAccessor, org.refcodes.exception.Trap

public class AmbiguousProxyException extends RemotingException
Thrown in case a proxy for a given type was requested but more than one proxy matched the requested type.
See Also: