Class ClassDescriptor

java.lang.Object
org.refcodes.remoting.ClassDescriptor
All Implemented Interfaces:
Serializable, org.refcodes.mixin.InstanceIdAccessor, org.refcodes.mixin.TypeAccessor, InstanceId

public class ClassDescriptor extends Object implements InstanceId, org.refcodes.mixin.TypeAccessor, Serializable
The most common information to be provided when describing an object residing in a RemoteServer and which is linked to a RemoteClient. The RemoteServer creates this descriptor and passes it to the RemoteClient, the RemoteClient attaches this information to a ProxyDescriptor describing its proxy instances.
See Also:
  • Constructor Details

    • ClassDescriptor

      public ClassDescriptor()
      Creates a new ClassDescriptor object.
    • ClassDescriptor

      public ClassDescriptor(Class<?> aClass, String aInstanceId)
      Constructs a ClassDescriptor instance with the given attributes.
      Parameters:
      aClass - The class for the subject in question.
      aInstanceId - The instance ID of the subject in question.
    • ClassDescriptor

      public ClassDescriptor(ClassDescriptor aClassDescriptor)
      Constructs a ClassDescriptor instance from the provided ClassDescriptor instance.
      Parameters:
      aClassDescriptor - The ClassDescriptor providing the instance ID and the type.
  • Method Details

    • getInstanceId

      public String getInstanceId()
      Specified by:
      getInstanceId in interface org.refcodes.mixin.InstanceIdAccessor
    • getType

      public Class<?> getType()
      Specified by:
      getType in interface org.refcodes.mixin.TypeAccessor
    • toString

      public String toString()
      Overrides:
      toString in class Object
    • setClass

      protected void setClass(Class<?> type)
      Sets the class.
      Parameters:
      type - Description is currently not available!
    • setClassDescriptor

      protected void setClassDescriptor(ClassDescriptor classDescriptor)
      Sets the class descriptor.
      Parameters:
      classDescriptor - Description is currently not available!
    • setInstanceId

      protected void setInstanceId(String instanceId)
      Sets the instance id.
      Parameters:
      instanceId - Description is currently not available!
    • clear

      protected void clear()
      Same as Clearable.clear().