Interface InstanceId

All Superinterfaces:
InstanceIdAccessor
All Known Subinterfaces:
ClientMessage, Message, MethodRequest, Reply, ServerMessage, Session
All Known Implementing Classes:
ClassDescriptor

public interface InstanceId extends InstanceIdAccessor
The InstanceId associates an instance ID to instances of the refcodes-remoting frame. The ID is used to identify method calls and replies and assigns them to the corresponding proxy (in case of a reply) or the actual object (in case of a request).