Interface MethodRequest

All Superinterfaces:
InstanceId, InstanceIdAccessor, Session, SessionIdAccessor

public interface MethodRequest extends Session
The Interface MethodRequest.
  • Method Details

    • getMethodName

      String getMethodName()
      Returns the name of the method represented by this method object, as a String.
      Returns:
      The name of the method represented by this method object is returned
    • getArgumentTypeArray

      Class<?>[] getArgumentTypeArray()
      Returns an array of Class objects that represent the formal parameter types, in declaration order, of the method represented by this Method object.
      Returns:
      Description is currently not available!
    • getArgumentArray

      Object[] getArgumentArray()
      Returns the arguments to be passed to the method which in turn will be invoked on the target object.
      Returns:
      The Object array being the arguments to be passed to the method of the target.