Class ProxyDisposedRuntimeException

All Implemented Interfaces:
Serializable, ErrorCodeAccessor, Trap

public class ProxyDisposedRuntimeException extends RemotingRuntimeException
This is a predictable exception. It is thrown by any object implementing the GenericDisposeable interface. This exception can be avoided by first testing the value returned by the method isDisposed() of the interface GenericDisposeable.
See Also: