Interface Reply

All Superinterfaces:
ExceptionAccessor<Throwable>, ExceptionAccessor.ExceptionMutator<Throwable>, ExceptionAccessor.ExceptionProperty<Throwable>, InstanceId, InstanceIdAccessor, Session, SessionIdAccessor

public interface Reply extends Session, ExceptionAccessor.ExceptionProperty<Throwable>
The Interface Reply.
  • Method Details

    • getReturnValue

      Object getReturnValue()
      Returns the return value of a method call. To test first if the reply does not contain a Throwable object (exception occurred!) use the method isThrowable().
      Returns:
      The return value of the method call (if any),
    • isException

      boolean isException()
      Returns true if the reply carries an exception which occurred when executing the method call.
      Returns:
      True if this object contains an exception (Throwable object) instead of a return value.
    • isReturnValue

      boolean isReturnValue()
      Returns true if the reply carries a valid return value.
      Returns:
      True if this object contains valid return value.
    • setReturnValue

      void setReturnValue(Object aValue)
      Sets the return value.
      Parameters:
      aValue - Description is currently not available!
    • setReply

      void setReply(Reply aReply)
      Sets a reply. The results (getThrowable(), getReturnValue()) from the provided reply are taken and set inside this instance. If this instance did not contain a reply before, then the method hasReply will return true from after this method call.
      Parameters:
      aReply - An object of type BlueprintMethodReply from which the replied values (throwable or return value) will be taken.
    • setException

      void setException(Throwable aException)
      Specified by:
      setException in interface ExceptionAccessor.ExceptionMutator<Throwable>
    • hasReply

      boolean hasReply()
      Returns true if this reply is not empty and waiting to be feeded with a reply. Important for an object waiting for a reply - when method setMethodReply() has been called, then thi method returns true, or if an instance has been created already containing a repy (not being empty).
      Returns:
      True if an instance of this interface (which did not contain a valid reply) has been feeded with a reply.