This method is invoked in order to trigger processing of the provided
Message, e.g. start execution depending on the Message
instance being provided from the outside.
This method is invoked in order to trigger processing of the provided
Message, e.g. start execution depending on the Message
instance being provided from the outside.