Class ProxyDisposedRuntimeException

java.lang.Object
java.lang.Throwable
java.lang.Exception
java.lang.RuntimeException
org.refcodes.exception.AbstractRuntimeException
org.refcodes.remoting.RemotingRuntimeException
org.refcodes.remoting.ProxyDisposedRuntimeException
All Implemented Interfaces:
Serializable, org.refcodes.exception.ErrorCodeAccessor, org.refcodes.exception.Trap

public class ProxyDisposedRuntimeException extends RemotingRuntimeException
This is a predictable exception. It is thrown by any object implementing the GenericDisposeable interface. This exception can be avoided by first testing the value returned by the method isDisposed() of the interface GenericDisposeable.
See Also: