Class RemoteClient
java.lang.Object
org.refcodes.component.AbstractConnectable
org.refcodes.component.AbstractConnectableAutomaton
org.refcodes.remoting.RemoteClient
- All Implemented Interfaces:
Closable, Closable.CloseAutomaton, ClosedAccessor, Component, ConnectableComponent, ConnectableComponent.ConnectableAutomaton, ConnectionComponent<DatagramTransceiver<Serializable>>, ConnectionComponent.ConnectionAutomaton<DatagramTransceiver<Serializable>>, ConnectionOpenable<DatagramTransceiver<Serializable>>, ConnectionOpenable.ConnectionOpenAutomaton<DatagramTransceiver<Serializable>>, ConnectionStatusAccessor, Destroyable, OpenedAccessor, BusyAccessor, Clearable, EmptyAccessor, Remote, Containable
A
RemoteClient promotes subjects to be operated on by a
RemoteServer.-
Nested Class Summary
Nested classes/interfaces inherited from interface BusyAccessor
BusyAccessor.BusyMutator, BusyAccessor.BusyPropertyNested classes/interfaces inherited from interface Closable
Closable.CloseAutomaton, Closable.CloseBuilder<B>Nested classes/interfaces inherited from interface ClosedAccessor
ClosedAccessor.ClosedMutator, ClosedAccessor.ClosedPropertyNested classes/interfaces inherited from interface ConnectableComponent
ConnectableComponent.ConnectableAutomatonNested classes/interfaces inherited from interface ConnectionComponent
ConnectionComponent.ConnectionAutomaton<CON>, ConnectionComponent.ConnectionComponentBuilder<CON,B> Nested classes/interfaces inherited from interface ConnectionOpenable
ConnectionOpenable.ConnectionOpenAutomaton<CON>, ConnectionOpenable.ConnectionOpenBuilder<CON,B> Nested classes/interfaces inherited from interface ConnectionStatusAccessor
ConnectionStatusAccessor.ConnectionStatusMutator, ConnectionStatusAccessor.ConnectionStatusPropertyNested classes/interfaces inherited from interface Destroyable
Destroyable.DestroyAutomatonNested classes/interfaces inherited from interface EmptyAccessor
EmptyAccessor.EmptyBuilder<B>, EmptyAccessor.EmptyMutator, EmptyAccessor.EmptyPropertyNested classes/interfaces inherited from interface OpenedAccessor
OpenedAccessor.OpenedMutator, OpenedAccessor.OpenedProperty -
Constructor Summary
ConstructorsConstructorDescriptionDefault constructor of theRemoteClientwill use a defaultExecutorService.RemoteClient(ExecutorService aExecutorService) Instantiates a newRemoteClientinstance with the givenExecutorServiceto be used. -
Method Summary
Modifier and TypeMethodDescriptionvoidclear()voidclose()protected voidCloses theRemoteupon a receivedCloseConnectionMessage.voiddestroy()protected voidprotected voidFor testing purposes, any job can be manually pushed into the job process to the receiver.protected voidfromSender(Message aJob) Provides anMessagefrom another sender to this receiver.protected ExecutorServiceHook method for retrieving theExecutorService.<T> TReturns the proxy which can be cast to the given type.booleanReturns true if there is at least one proxy of the given type.booleanReturns true if the provided proxy is contained inside theRemoteClient.booleanisBusy()protected booleanHook to support theDestroyableinterface, determines the destroyed status property; set to true whenDestroyable.destroy()is called.booleanisEmpty()booleanisOpenable(DatagramTransceiver<Serializable> aConnection) protected voidonClosed()Hook when the connection has been closed.protected voidonOpened()Hook when the connection has been opened.protected voidonProxyPublished(Object aProxy) Hook when a proxy has been published.protected voidonProxySignedOff(Object aProxy) Hook when a proxy has been signed-off.protected voidonPublishProxy(Class<?> aType) Hook when a proxy is about to be published.voidopen(DatagramTransceiver<Serializable> aTransceiver) proxies()Returns a read-only iterator containing all the proxy objects previously being published.booleansignOffProxy(Object aProxy) Signs off an instance previously published using the publishClassDescriptor() method.intsize()protected voidtoReceiver(Message aJob) Forwards anMessagefrom this sender to another receiver.Methods inherited from class AbstractConnectableAutomaton
getConnectionStatus, isClosable, isClosed, isOpenable, isOpened, open, setConnectionStatusMethods inherited from class AbstractConnectable
isThrownAsOfAlreadyClosedMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface Closable
closeIn, closeQuietly, closeUncheckedMethods inherited from interface Closable.CloseAutomaton
isClosableMethods inherited from interface ClosedAccessor
isClosedMethods inherited from interface ConnectionOpenable
openUncheckedMethods inherited from interface ConnectionStatusAccessor
getConnectionStatus, isOpened
-
Constructor Details
-
RemoteClient
public RemoteClient()Default constructor of theRemoteClientwill use a defaultExecutorService. -
RemoteClient
Instantiates a newRemoteClientinstance with the givenExecutorServiceto be used.- Parameters:
aExecutorService- TheExecutorServiceto be used.
-
-
Method Details
-
clear
public void clear() -
close
- Specified by:
closein interfaceClosable- Throws:
IOException
-
isBusy
public boolean isBusy() -
hasProxy
Returns true if the provided proxy is contained inside theRemoteClient.- Parameters:
aProxy- The proxy to be tested if it is contained inside theRemoteClient.- Returns:
- True if the given proxy is contained inside the
RemoteClient.
-
getProxy
Returns the proxy which can be cast to the given type. Note that this method may throw anAmbiguousProxyExceptioneven ifhasProxy(Class)returns true! The methodhasProxy(Class)returns true in case at least one proxy of the given type was found whereas this method only returns a proxy in case there is exactly one proxy of the required type is present.- Type Parameters:
T- the generic type- Parameters:
aType- the type- Returns:
- The proxy for an instance of the given type.
- Throws:
AmbiguousProxyException- Thrown in case a proxy for a given type was requested but more than one proxies matched the requested type.NoSuchProxyException- Thrown in case a proxy for a given type was requested but not any proxy matched the requested type.
-
hasProxy
Returns true if there is at least one proxy of the given type.- Parameters:
aType- the type- Returns:
- True in case there is at least one proxy of the given type.
-
proxies
-
isEmpty
public boolean isEmpty() -
signOffProxy
Signs off an instance previously published using the publishClassDescriptor() method.- Parameters:
aProxy- An object of type GenericInstanceDescriptor containing the information needed to sign-off an instance.- Returns:
- True is returned if the instance described by the proxy object could be signed off, else false is returned
- Throws:
IOException- Thrown in case opening or accessing an open line (connection, junction, link) caused problems.
-
size
public int size() -
destroy
public void destroy()- Specified by:
destroyin interfaceDestroyable
-
doSendJob
For testing purposes, any job can be manually pushed into the job process to the receiver.- Parameters:
aJob- The job to be pushed to the receiver.- Throws:
IOException- Thrown in case the operation failed due to an I/O malfunction such as the input- or output-connection (of an input- and output-connection pair) is not available or being disconnected.
-
digest
This method is invoked in order to trigger processing of the providedMessage, e.g. start execution depending on theMessageinstance being provided from the outside. ARemoteClientdigests such aMessagedifferent than aRemoteServer. This method is inspired by theDigester.digest(Object)method.- Parameters:
aJob- TheMessageto be digested.- Throws:
DigestException- Thrown in case digesting (processing) a job by aDigester.digest(Object)caused problems; the aCause is usually wrapped by thisException.- See Also:
-
close
Closes theRemoteupon a receivedCloseConnectionMessage. Some client ID might be considered in order to determine whether to close all or just one of many connections. This default implementation callsClosable.close()(setting theConnectionStatusto beConnectionStatus.CLOSED); advanced implementations just closing dedicated connections may keep theRemoteitself open (and skip callingClosable.close()and close only a dedicated connection identified by the Meta-Data of theCloseConnectionMessage.- Parameters:
aJob- TheCloseConnectionMessagebeing received for closing the connection.
-
onPublishProxy
Hook when a proxy is about to be published.- Parameters:
aType- The type to be stored by the property.- Throws:
VetoException- Thrown to signal that an operation is being vetoed by a third party observing the invocation of the given operation.
-
onProxyPublished
Hook when a proxy has been published.- Parameters:
aProxy- The proxy to being published.
-
onProxySignedOff
Hook when a proxy has been signed-off.- Parameters:
aProxy- The proxy which has been signed-off.
-
isOpenable
- Specified by:
isOpenablein interfaceConnectionOpenable.ConnectionOpenAutomaton<DatagramTransceiver<Serializable>>
-
open
- Specified by:
openin interfaceConnectionOpenable<DatagramTransceiver<Serializable>>- Throws:
IOException
-
toReceiver
Forwards anMessagefrom this sender to another receiver. A sub-class invokes this method when it sends anMessageto the receiver counterpart. The communication path is to be implemented by the sub-class.- Parameters:
aJob- theMessageto be forwarded to this receiver from the sender counterpart.- Throws:
IOException- Thrown in case opening or accessing an open line (connection, junction, link) caused problems.
-
fromSender
-
getExecutorService
Hook method for retrieving theExecutorService.- Returns:
- The
ExecutorServiceas used by this implementation.
-
isDestroyed
protected boolean isDestroyed()Hook to support theDestroyableinterface, determines the destroyed status property; set to true whenDestroyable.destroy()is called.- Returns:
- The destroyed status property.
-
onOpened
protected void onOpened()Hook when the connection has been opened. -
onClosed
protected void onClosed()Hook when the connection has been closed.
-