The AbstractRemote.digest(Message) method is invoked in order to trigger
processing of the provided Message, e.g. start execution
depending on the Message instance being provided from the
outside.
The AbstractRemote.digest(Message) method is invoked in order to trigger
processing of the provided Message, e.g. start execution
depending on the Message instance being provided from the
outside.